@@ -500,7 +500,7 @@ class SBtabTable():
         table_string = [self.header_row]
         table_string.append('\t'.join(self.columns))
         for row in self.value_rows:
-            row = '\t'.join(row)
+            row = '\t'.join(str(p) for p in row)
             table_string.append(row)
             
         return '\n'.join(table_string)
